@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::AnyViewer;
-$Config::Model::Tk::AnyViewer::VERSION = '1.362';
+$Config::Model::Tk::AnyViewer::VERSION = '1.363';
 use strict;
 use warnings;
 use Carp;
@@ -67,7 +67,6 @@ sub add_header {
 my @top_frame_args = qw/-relief raised -borderwidth 4/;
 my @low_frame_args = qw/-relief sunken -borderwidth 1/;
 my $padx           = 20;
-my $text_font      = [qw/-family Arial -weight normal/];
 
 sub add_info_button {
     my $cw = shift;
@@ -81,7 +80,6 @@ sub add_info_button {
     my $dialog = $cw->Dialog(
         -title => $title,
         -text  => join( "\n", $title, @items ),
-        -font  => $text_font,
     );
     my $button = $frame->Button(
         -text    => "info ...",
@@ -130,7 +128,6 @@ sub add_help {
         $widget = $help_frame->Label(
             -text    => $help,
             -justify => 'left',
-            -font    => $text_font,
             -anchor  => 'w',
             -padx    => $padx,
         )->pack( -fill => 'x' );
@@ -189,7 +186,6 @@ sub add_warning {
         'ROText',
         -scrollbars => 'ow',
         -wrap       => 'word',
-        -font       => $text_font,
         -relief     => 'ridge',
         -height     => 4,
     );
