@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::CheckListEditor;
-$Config::Model::Tk::CheckListEditor::VERSION = '1.362';
+$Config::Model::Tk::CheckListEditor::VERSION = '1.363';
 use strict;
 use warnings;
 use Carp;
@@ -48,6 +48,7 @@ sub Populate {
         || die "CheckListEditor: no -item, got ", keys %$args;
     delete $args->{-path};
     $cw->{store_cb} = delete $args->{-store_cb} || die __PACKAGE__, "no -store_cb";
+    my $cme_font = delete $args->{-font};
 
     my $inst = $leaf->instance;
 
@@ -118,6 +119,7 @@ sub Populate {
     }
 
     $cw->Advertise( 'listbox' => $lb );
+    $cw->ConfigSpecs(-font => [['SELF','DESCENDANTS'], 'font','Font', $cme_font ],);
 
     # don't call directly SUPER::Populate as it's CheckListViewer's populate
     $cw->Tk::Frame::Populate($args);
